@@ -51,4 +51,11 @@ def rings(features_X, features_position, max_radio=[0.00014, 0.00024, 0.00034],
             final_features_df[f"{feature}_{i}"] = features_array[f_index]
         
     features_X = final_features_df
-    return features_X
\ No newline at end of file
+    return features_X
+
+
+"""
+Revisar promedio de vecinos para los anillos
+Decidir si usar metros o no (ahora está en grados ?)
+
+"""
\ No newline at end of file
